==> openshift-model-hive-5.12.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterPoolSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterPoolSpecBuilder extends io.fabric8.openshift.api.model.hive.v1.ClusterPoolSpecFluentImpl<io.fabric8.openshift.api.model.hive.v1.ClusterPoolSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.ClusterPoolSpec,io.fabric8.openshift.api.model.hive.v1.ClusterPoolSpecBuilder>{
  public ClusterPoolSpecBuilder() {
    this(false);
  }
  public ClusterPoolSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterPoolSpec(), validationEnabled);
  }
  public ClusterPoolSpecBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterPoolSpecBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterPoolSpec(), validationEnabled);
  }
  public ClusterPoolSpecBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolSpecFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterPoolSpec instance) {
    this(fluent, instance, false);
  }
  public ClusterPoolSpecBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolSpecFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterPoolSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAnnotations(instance.getAnnotations()); 
    fluent.withBaseDomain(instance.getBaseDomain()); 
    fluent.withClaimLifetime(instance.getClaimLifetime()); 
    fluent.withHibernateAfter(instance.getHibernateAfter()); 
    fluent.withImageSetRef(instance.getImageSetRef()); 
    fluent.withInstallAttemptsLimit(instance.getInstallAttemptsLimit()); 
    fluent.withInstallConfigSecretTemplateRef(instance.getInstallConfigSecretTemplateRef()); 
    fluent.withLabels(instance.getLabels()); 
    fluent.withMaxConcurrent(instance.getMaxConcurrent()); 
    fluent.withMaxSize(instance.getMaxSize()); 
    fluent.withPlatform(instance.getPlatform()); 
    fluent.withPullSecretRef(instance.getPullSecretRef()); 
    fluent.withRunningCount(instance.getRunningCount()); 
    fluent.withSize(instance.getSize()); 
    fluent.withSkipMachinePools(instance.getSkipMachinePools()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterPoolSpecBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolSpec instance) {
    this(instance,false);
  }
  public ClusterPoolSpecBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterPoolSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAnnotations(instance.getAnnotations()); 
    this.withBaseDomain(instance.getBaseDomain()); 
    this.withClaimLifetime(instance.getClaimLifetime()); 
    this.withHibernateAfter(instance.getHibernateAfter()); 
    this.withImageSetRef(instance.getImageSetRef()); 
    this.withInstallAttemptsLimit(instance.getInstallAttemptsLimit()); 
    this.withInstallConfigSecretTemplateRef(instance.getInstallConfigSecretTemplateRef()); 
    this.withLabels(instance.getLabels()); 
    this.withMaxConcurrent(instance.getMaxConcurrent()); 
    this.withMaxSize(instance.getMaxSize()); 
    this.withPlatform(instance.getPlatform()); 
    this.withPullSecretRef(instance.getPullSecretRef()); 
    this.withRunningCount(instance.getRunningCount()); 
    this.withSize(instance.getSize()); 
    this.withSkipMachinePools(instance.getSkipMachinePools()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.ClusterPoolSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.ClusterPoolSpec build() {
    ClusterPoolSpec buildable = new ClusterPoolSpec(fluent.getAnnotations(),fluent.getBaseDomain(),fluent.getClaimLifetime(),fluent.getHibernateAfter(),fluent.getImageSetRef(),fluent.getInstallAttemptsLimit(),fluent.getInstallConfigSecretTemplateRef(),fluent.getLabels(),fluent.getMaxConcurrent(),fluent.getMaxSize(),fluent.getPlatform(),fluent.getPullSecretRef(),fluent.getRunningCount(),fluent.getSize(),fluent.getSkipMachinePools());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterPoolSpecBuilder that = (ClusterPoolSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.5.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterPoolSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterPoolSpecBuilder extends ClusterPoolSpecFluentImpl<ClusterPoolSpecBuilder> implements VisitableBuilder<ClusterPoolSpec,ClusterPoolSpecBuilder>{
  public ClusterPoolSpecBuilder() {
    this(false);
  }
  public ClusterPoolSpecBuilder(Boolean validationEnabled) {
    this(new ClusterPoolSpec(), validationEnabled);
  }
  public ClusterPoolSpecBuilder(ClusterPoolSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterPoolSpecBuilder(ClusterPoolSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterPoolSpec(), validationEnabled);
  }
  public ClusterPoolSpecBuilder(ClusterPoolSpecFluent<?> fluent,ClusterPoolSpec instance) {
    this(fluent, instance, false);
  }
  public ClusterPoolSpecBuilder(ClusterPoolSpecFluent<?> fluent,ClusterPoolSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAnnotations(instance.getAnnotations()); 
    fluent.withBaseDomain(instance.getBaseDomain()); 
    fluent.withClaimLifetime(instance.getClaimLifetime()); 
    fluent.withHibernateAfter(instance.getHibernateAfter()); 
    fluent.withImageSetRef(instance.getImageSetRef()); 
    fluent.withInstallAttemptsLimit(instance.getInstallAttemptsLimit()); 
    fluent.withInstallConfigSecretTemplateRef(instance.getInstallConfigSecretTemplateRef()); 
    fluent.withLabels(instance.getLabels()); 
    fluent.withMaxConcurrent(instance.getMaxConcurrent()); 
    fluent.withMaxSize(instance.getMaxSize()); 
    fluent.withPlatform(instance.getPlatform()); 
    fluent.withPullSecretRef(instance.getPullSecretRef()); 
    fluent.withRunningCount(instance.getRunningCount()); 
    fluent.withSize(instance.getSize()); 
    fluent.withSkipMachinePools(instance.getSkipMachinePools()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterPoolSpecBuilder(ClusterPoolSpec instance) {
    this(instance,false);
  }
  public ClusterPoolSpecBuilder(ClusterPoolSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAnnotations(instance.getAnnotations()); 
    this.withBaseDomain(instance.getBaseDomain()); 
    this.withClaimLifetime(instance.getClaimLifetime()); 
    this.withHibernateAfter(instance.getHibernateAfter()); 
    this.withImageSetRef(instance.getImageSetRef()); 
    this.withInstallAttemptsLimit(instance.getInstallAttemptsLimit()); 
    this.withInstallConfigSecretTemplateRef(instance.getInstallConfigSecretTemplateRef()); 
    this.withLabels(instance.getLabels()); 
    this.withMaxConcurrent(instance.getMaxConcurrent()); 
    this.withMaxSize(instance.getMaxSize()); 
    this.withPlatform(instance.getPlatform()); 
    this.withPullSecretRef(instance.getPullSecretRef()); 
    this.withRunningCount(instance.getRunningCount()); 
    this.withSize(instance.getSize()); 
    this.withSkipMachinePools(instance.getSkipMachinePools()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ClusterPoolSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterPoolSpec build() {
    ClusterPoolSpec buildable = new ClusterPoolSpec(fluent.getAnnotations(),fluent.getBaseDomain(),fluent.getClaimLifetime(),fluent.getHibernateAfter(),fluent.getImageSetRef(),fluent.getInstallAttemptsLimit(),fluent.getInstallConfigSecretTemplateRef(),fluent.getLabels(),fluent.getMaxConcurrent(),fluent.getMaxSize(),fluent.getPlatform(),fluent.getPullSecretRef(),fluent.getRunningCount(),fluent.getSize(),fluent.getSkipMachinePools());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
